@@ -28,10 +28,12 @@
 static char dev_null[20] = "";
 
 #ifdef _WIN32
+#define SHELL_IS_CMD_EXE
 static const char *exe_ext = ".exe";
 static const char *obj_ext = ".obj";
 static const char *local_command_start = ".\\";
 #else
+#define SHELL_IS_POSIX
 static const char *exe_ext = "";
 static const char *obj_ext = "";
 static const char *local_command_start = "./";
@@ -89,11 +91,6 @@ S_probe_dev_null(void) {
 #endif
 }
 
-void
-OS_clean_up(void) {
-    OS_remove_exe("_charm_run");
-}
-
 const char*
 OS_exe_ext(void) {
     return exe_ext;
@@ -109,59 +106,6 @@ OS_dev_null(void) {
     return dev_null;
 }
 
-static const char charm_run_code[] =
-    QUOTE(  #include <stdio.h>                                           )
-    QUOTE(  #include <stdlib.h>                                          )
-    QUOTE(  #include <string.h>                                          )
-    QUOTE(  #include <stddef.h>                                          )
-    QUOTE(  int main(int argc, char **argv)                              )
-    QUOTE(  {                                                            )
-    QUOTE(      char *command;                                           )
-    QUOTE(      size_t command_len = 1; /* Terminating null. */          )
-    QUOTE(      int i;                                                   )
-    QUOTE(      int retval;                                              )
-    /* Rebuild command line args. */
-    QUOTE(      for (i = 1; i < argc; i++) {                             )
-    QUOTE(          command_len += strlen(argv[i]) + 1;                  )
-    QUOTE(      }                                                        )
-    QUOTE(      command = (char*)calloc(command_len, sizeof(char));      )
-    QUOTE(      if (command == NULL) {                                   )
-    QUOTE(          fprintf(stderr, "calloc failed\n");                  )
-    QUOTE(          exit(1);                                             )
-    QUOTE(      }                                                        )
-    QUOTE(      for (i = 1; i < argc; i++) {                             )
-    QUOTE(          strcat( strcat(command, " "), argv[i] );             )
-    QUOTE(      }                                                        )
-    /* Redirect all output to /dev/null or equivalent. */
-    QUOTE(      freopen("%s", "w", stdout);                              )
-    QUOTE(      freopen("%s", "w", stderr);                              )
-    /* Run commmand and return its value to parent. */
-    QUOTE(      retval = system(command);                                )
-    QUOTE(      free(command);                                           )
-    QUOTE(      return retval;                                           )
-    QUOTE(  }                                                            );
-
-static void
-S_build_charm_run(void) {
-    chaz_bool_t compile_succeeded = false;
-    size_t needed = sizeof(charm_run_code)
-                    + strlen(dev_null)
-                    + strlen(dev_null)
-                    + 20;
-    char *code = (char*)malloc(needed);
-
-    sprintf(code, charm_run_code, dev_null, dev_null);
-    compile_succeeded = CC_compile_exe("_charm_run.c", "_charm_run",
-                                       code, strlen(code));
-    if (!compile_succeeded) {
-        Util_die("failed to compile _charm_run helper utility");
-    }
-
-    remove("_charm_run.c");
-    free(code);
-    charm_run_ok = true;
-}
-
 void
 OS_remove_exe(const char *name) {
     char *exe_name = (char*)malloc(strlen(name) + strlen(exe_ext) + 1);
@@ -210,22 +154,41 @@ OS_run_quietly(const char *command) {
     size_t size = sizeof(pattern) + strlen(command) + 10;
     char *quiet_command = (char*)malloc(size);
     sprintf(quiet_command, pattern, command);
+#else
+    char pattern[] = "%s > %s 2>&1";
+    size_t size = sizeof(pattern) + strlen(command) + strlen(dev_null) + 10;
+    char *quiet_command = (char*)malloc(size);
+    sprintf(quiet_command, pattern, command, dev_null);
+#endif
     retval = system(quiet_command);
     free(quiet_command);
-#else
-    if (!charm_run_initialized) {
-        charm_run_initialized = true;
-        S_build_charm_run();
-    }
-    if (!charm_run_ok) {
-        retval = system(command);
-    }
-    else {
-        retval = OS_run_local("_charm_run ", command, NULL);
-    }
-#endif
 
     return retval;
 }
 
+void
+OS_mkdir(const char *filepath) {
+    #if (defined(SHELL_IS_POSIX) || defined (SHELL_IS_CMD_EXE))
+    char *mkdir_command = "mkdir";
+    #endif
+    unsigned size = strlen(mkdir_command) + 1 + strlen(filepath) + 1;
+    char *command = (char*)malloc(size);
+    sprintf(command, "%s %s", mkdir_command, filepath);
+    OS_run_quietly(command);
+    free(command);
+}
+
+void
+OS_rmdir(const char *filepath) {
+    #ifdef SHELL_IS_POSIX
+    char *rmdir_command = "rmdir";
+    #elif defined(SHELL_IS_CMD_EXE)
+    char *rmdir_command = "rmdir /q";
+    #endif
+    unsigned size = strlen(rmdir_command) + 1 + strlen(filepath) + 1;
+    char *command = (char*)malloc(size);
+    sprintf(command, "%s %s", rmdir_command, filepath);
+    OS_run_quietly(command);
+    free(command);
+}
 
