@@ -22,18 +22,19 @@
 #include "Charmonizer/Test.h"
 
 static void
-S_run_tests(TestBatch *batch) {
+S_run_tests(void) {
     char buf[10];
     chaz_bool_t really_has_var_macs = false;
 
 #if defined(HAS_ISO_VARIADIC_MACROS) || defined(HAS_GNUC_VARIADIC_MACROS)
   #ifdef HAS_VARIADIC_MACROS
-    PASS(batch, "#defines agree");
+    PASS("#defines agree");
   #else
-    FAIL(batch, 0, "#defines agree");
+    FAIL(0, "#defines agree");
   #endif
 #else
-    SKIP_REMAINING(batch, "No variadic macro support");
+    SKIP_REMAINING("No variadic macro support");
+    return;
 #endif
 
 
@@ -42,9 +43,9 @@ S_run_tests(TestBatch *batch) {
     sprintf(buffer, fmt, __VA_ARGS__)
     really_has_var_macs = true;
     ISO_TEST(buf, "%s", "iso");
-    TEST_STR_EQ(batch, buf, "iso", "ISO variadic macros work");
+    STR_EQ(buf, "iso", "ISO variadic macros work");
 #else
-    SKIP(batch, "No ISO variadic macros");
+    SKIP("No ISO variadic macros");
 #endif
 
 #ifdef HAS_GNUC_VARIADIC_MACROS
@@ -52,21 +53,17 @@ S_run_tests(TestBatch *batch) {
     sprintf(buffer, fmt, ##args )
     really_has_var_macs = true;
     GNU_TEST(buf, "%s", "gnu");
-    TEST_STR_EQ(batch, buf, "gnu", "GNUC variadic macros work");
+    STR_EQ(buf, "gnu", "GNUC variadic macros work");
 #else
-    SKIP(batch, "No GNUC variadic macros");
+    SKIP("No GNUC variadic macros");
 #endif
 
-    TEST_TRUE(batch, really_has_var_macs, "either ISO or GNUC");
+    OK(really_has_var_macs, "either ISO or GNUC");
 }
 
-
 int main(int argc, char **argv) {
-    TestBatch *batch;
-
-    Test_init();
-    batch = Test_new_batch("VariadicMacros", 4, S_run_tests);
-    batch->run_test(batch);
-    batch->destroy(batch);
-    return 0;
+    Test_start(4);
+    S_run_tests();
+    return !Test_finish();
 }
+
