@@ -263,25 +263,6 @@ CFCUtil_flength(void *file) {
     return len;
 }
 
-void
-CFCUtil_die(const char* format, ...) {
-    va_list args;
-    va_start(args, format);
-    vfprintf(stderr, format, args);
-    va_end(args);
-    fprintf(stderr, "\n");
-    exit(1);
-}
-
-void
-CFCUtil_warn(const char* format, ...) {
-    va_list args;
-    va_start(args, format);
-    vfprintf(stderr, format, args);
-    va_end(args);
-    fprintf(stderr, "\n");
-}
-
 // Note: this has to be defined before including the Perl headers because they
 // redefine stat() in an incompatible way on certain systems (Windows).
 int
@@ -426,7 +407,7 @@ CFCUtil_dirnext(void *dirhandle) {
 
 void
 CFCUtil_closedir(void *dirhandle, const char *dir) {
-    if (closedir(dirhandle) == -1) {
+    if (closedir((DIR*)dirhandle) == -1) {
         CFCUtil_die("Error closing dir '%s': %s", dir, strerror(errno));
     }
 }
@@ -435,23 +416,54 @@ CFCUtil_closedir(void *dirhandle, const char *dir) {
 
 /***************************************************************************/
 
+#ifdef CFCPERL
+
 #include "EXTERN.h"
 #include "perl.h"
 #include "XSUB.h"
 #include "ppport.h"
 
-void*
-CFCUtil_make_perl_obj(void *ptr, const char *klass) {
-    SV *inner_obj = newSV(0);
-    SvOBJECT_on(inner_obj);
-    PL_sv_objcount++;
-    SvUPGRADE(inner_obj, SVt_PVMG);
-    sv_setiv(inner_obj, PTR2IV(ptr));
-
-    // Connect class association.
-    HV *stash = gv_stashpvn((char*)klass, strlen(klass), TRUE);
-    SvSTASH_set(inner_obj, (HV*)SvREFCNT_inc(stash));
-
-    return  inner_obj;
+void
+CFCUtil_die(const char* format, ...) {
+    SV *errsv = get_sv("@", 1);
+    va_list args;
+    va_start(args, format);
+    sv_vsetpvf_mg(errsv, format, &args);
+    va_end(args);
+    croak(NULL);
 }
 
+void
+CFCUtil_warn(const char* format, ...) {
+    SV *mess = newSVpv("", 0);
+    va_list args;
+    va_start(args, format);
+    sv_vsetpvf(mess, format, &args);
+    va_end(args);
+    fprintf(stderr, "%s\n", SvPV_nolen(mess));
+    SvREFCNT_dec(mess);
+}
+
+#else
+
+void
+CFCUtil_die(const char* format, ...) {
+    va_list args;
+    va_start(args, format);
+    vfprintf(stderr, format, args);
+    va_end(args);
+    fprintf(stderr, "\n");
+    exit(1);
+}
+
+void
+CFCUtil_warn(const char* format, ...) {
+    va_list args;
+    va_start(args, format);
+    vfprintf(stderr, format, args);
+    va_end(args);
+    fprintf(stderr, "\n");
+}
+
+#endif /* CFCPERL */
+
