@@ -14,13 +14,8 @@
  * limitations under the License.
  */
 
-#include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
-#include <ctype.h>
-#include "EXTERN.h"
-#include "perl.h"
-#include "XSUB.h"
-#include "ppport.h"
 
 #ifndef true
   #define true 1
@@ -40,25 +35,34 @@ struct CFCVariable {
     char *local_c;
     char *global_c;
     char *local_dec;
+    int   inert;
+};
+
+const static CFCMeta CFCVARIABLE_META = {
+    "Clownfish::CFC::Variable",
+    sizeof(CFCVariable),
+    (CFCBase_destroy_t)CFCVariable_destroy
 };
 
 CFCVariable*
 CFCVariable_new(struct CFCParcel *parcel, const char *exposure,
                 const char *class_name, const char *class_cnick,
-                const char *micro_sym, struct CFCType *type) {
-    CFCVariable *self = (CFCVariable*)CFCBase_allocate(sizeof(CFCVariable),
-                                                       "Clownfish::Variable");
+                const char *micro_sym, struct CFCType *type, int inert) {
+    CFCVariable *self = (CFCVariable*)CFCBase_allocate(&CFCVARIABLE_META);
     return CFCVariable_init(self, parcel, exposure, class_name, class_cnick,
-                            micro_sym, type);
+                            micro_sym, type, inert);
 }
 
 CFCVariable*
 CFCVariable_init(CFCVariable *self, struct CFCParcel *parcel,
                  const char *exposure, const char *class_name,
                  const char *class_cnick, const char *micro_sym,
-                 struct CFCType *type) {
-    // Validate type.
+                 struct CFCType *type, int inert) {
+    // Validate params.
     CFCUTIL_NULL_CHECK(type);
+    if (!parcel) {
+        parcel = CFCParcel_singleton(NULL, NULL);
+    }
 
     // Default exposure to "local".
     const char *real_exposure = exposure ? exposure : "local";
@@ -66,8 +70,9 @@ CFCVariable_init(CFCVariable *self, struct CFCParcel *parcel,
     CFCSymbol_init((CFCSymbol*)self, parcel, real_exposure, class_name,
                    class_cnick, micro_sym);
 
-    // Assign type.
+    // Assign type, inert.
     self->type = (CFCType*)CFCBase_incref((CFCBase*)type);
+    self->inert = !!inert;
 
     // Cache various C string representations.
     const char *type_str = CFCType_to_c(type);
@@ -75,23 +80,17 @@ CFCVariable_init(CFCVariable *self, struct CFCParcel *parcel,
     if (CFCType_is_composite(type) && CFCType_get_array(type) != NULL) {
         postfix = CFCType_get_array(type);
     }
-    {
-        size_t size = strlen(type_str) + sizeof(" ") + strlen(micro_sym) +
-                      strlen(postfix) + 1;
-        self->local_c = (char*)MALLOCATE(size);
-        sprintf(self->local_c, "%s %s%s", type_str, micro_sym, postfix);
-    }
-    {
-        self->local_dec = (char*)MALLOCATE(strlen(self->local_c) + sizeof(";\0"));
-        sprintf(self->local_dec, "%s;", self->local_c);
-    }
-    {
-        const char *full_sym = CFCVariable_full_sym(self);
-        size_t size = strlen(type_str) + sizeof(" ") + strlen(full_sym) +
-                      strlen(postfix) + 1;
-        self->global_c = (char*)MALLOCATE(size);
-        sprintf(self->global_c, "%s %s%s", type_str, full_sym, postfix);
-    }
+    size_t size = strlen(type_str) + sizeof(" ") + strlen(micro_sym) +
+                  strlen(postfix) + 1;
+    self->local_c = (char*)MALLOCATE(size);
+    sprintf(self->local_c, "%s %s%s", type_str, micro_sym, postfix);
+    self->local_dec = (char*)MALLOCATE(strlen(self->local_c) + sizeof(";\0"));
+    sprintf(self->local_dec, "%s;", self->local_c);
+    const char *full_sym = CFCVariable_full_sym(self);
+    size_t full_size = strlen(type_str) + sizeof(" ") + strlen(full_sym) +
+                       strlen(postfix) + 1;
+    self->global_c = (char*)MALLOCATE(full_size);
+    sprintf(self->global_c, "%s %s%s", type_str, full_sym, postfix);
 
     return self;
 }
@@ -116,6 +115,11 @@ CFCVariable_get_type(CFCVariable *self) {
     return self->type;
 }
 
+int
+CFCVariable_inert(CFCVariable *self) {
+    return self->inert;
+}
+
 const char*
 CFCVariable_local_c(CFCVariable *self) {
     return self->local_c;
