@@ -21,12 +21,12 @@ package Lucy;
 use 5.008003;
 use Exporter;
 
-our $VERSION = '0.003000';
+our $VERSION = '0.003001';
 $VERSION = eval $VERSION;
 
 use XSLoader;
 # This loads a large number of disparate subs.
-BEGIN { XSLoader::load( 'Lucy', '0.003000' ) }
+BEGIN { XSLoader::load( 'Lucy', '0.3.1' ) }
 
 BEGIN {
     push our @ISA, 'Exporter';
@@ -47,6 +47,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Util::IndexFileNames;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     BEGIN {
         push our @ISA, 'Exporter';
         our @EXPORT_OK = qw(
@@ -58,6 +60,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Util::StringHelper;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     BEGIN {
         push our @ISA, 'Exporter';
         our @EXPORT_OK = qw(
@@ -74,6 +78,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Analysis::Inversion;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     our %new_PARAMS = (
         # params
@@ -83,6 +89,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Analysis::Token;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     our %new_PARAMS = (
         text         => undef,
@@ -95,6 +103,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Analysis::RegexTokenizer;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     sub compile_token_re { return qr/$_[1]/ }
 
@@ -108,6 +118,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Document::Doc;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use Storable qw( nfreeze thaw );
     use bytes;
     no bytes;
@@ -139,6 +151,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Document::HitDoc;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     our %new_PARAMS = (
         fields => undef,
@@ -149,23 +163,31 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Object::I32Array;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     our %new_PARAMS = ( ints => undef );
 }
 
 {
     package Lucy::Object::LockFreeRegistry;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     no warnings 'redefine';
     sub DESTROY { }    # leak all
 }
 
 {
     package Lucy::Object::Obj;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use Lucy qw( to_clownfish to_perl );
     sub load { return $_[0]->_load( to_clownfish( $_[1] ) ) }
 }
 
 {
     package Lucy::Object::VTable;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     sub find_parent_class {
         my ( undef, $package ) = @_;
@@ -206,6 +228,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Index::Indexer;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     sub new {
         my ( $either, %args ) = @_;
@@ -220,6 +244,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Index::IndexReader;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use Carp;
 
     sub new {
@@ -243,6 +269,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Index::PolyReader;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use Lucy qw( to_clownfish );
 
     sub try_read_snapshot {
@@ -284,6 +312,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Index::Segment;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use Lucy qw( to_clownfish );
     sub store_metadata {
         my ( $self, %args ) = @_;
@@ -294,6 +324,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Index::SegReader;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     sub try_init_components {
         my $self = shift;
@@ -306,11 +338,15 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Index::SortCache;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     our %value_PARAMS = ( ord => undef, );
 }
 
 {
     package Lucy::Search::Compiler;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use Carp;
     use Scalar::Util qw( blessed );
 
@@ -328,6 +364,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Search::Query;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     sub make_compiler {
         my ( $self, %args ) = @_;
@@ -338,6 +376,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Search::SortRule;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     my %types = (
         field  => FIELD(),
@@ -355,11 +395,15 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Object::BitVector;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     sub to_arrayref { shift->to_array->to_arrayref }
 }
 
 {
     package Lucy::Object::ByteBuf;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     {
         # Override autogenerated deserialize binding.
         no warnings 'redefine';
@@ -369,12 +413,16 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Object::ViewByteBuf;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use Carp;
     sub new { confess "ViewByteBuf objects can only be created from C." }
 }
 
 {
     package Lucy::Object::CharBuf;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     {
         # Defeat obscure bugs in the XS auto-generation by redefining clone()
@@ -389,12 +437,16 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Object::ViewCharBuf;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use Carp;
     sub new { confess "ViewCharBuf has no public constructor." }
 }
 
 {
     package Lucy::Object::ZombieCharBuf;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use Carp;
     sub new { confess "ZombieCharBuf objects can only be created from C." }
     no warnings 'redefine';
@@ -403,6 +455,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Object::Err;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     sub do_to_string { shift->to_string }
     use Scalar::Util qw( blessed );
     use Carp qw( confess longmess );
@@ -440,12 +494,16 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Object::Hash;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     no warnings 'redefine';
     sub deserialize { shift->_deserialize(@_) }
 }
 
 {
     package Lucy::Object::VArray;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     no warnings 'redefine';
     sub clone       { CORE::shift->_clone }
     sub deserialize { CORE::shift->_deserialize(@_) }
@@ -453,6 +511,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Store::FileHandle;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     BEGIN {
         push our @ISA, 'Exporter';
         our @EXPORT_OK = qw( build_fh_flags );
@@ -478,6 +538,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Store::FSFileHandle;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     sub open {
         my ( $either, %args ) = @_;
@@ -489,12 +551,16 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Store::FSFolder;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     use File::Spec::Functions qw( rel2abs );
     sub absolutify { return rel2abs( $_[1] ) }
 }
 
 {
     package Lucy::Store::RAMFileHandle;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
 
     sub open {
         my ( $either, %args ) = @_;
@@ -506,6 +572,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Util::Debug;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     BEGIN {
         push our @ISA, 'Exporter';
         our @EXPORT_OK = qw(
@@ -523,6 +591,8 @@ sub error {$Lucy::Object::Err::error}
 
 {
     package Lucy::Object::Host;
+    our $VERSION = '0.003001';
+    $VERSION = eval $VERSION;
     BEGIN {
         if ( !__PACKAGE__->isa('Lucy::Object::Obj') ) {
             push our @ISA, 'Lucy::Object::Obj';
