@@ -17,6 +17,9 @@ use strict;
 use warnings;
 
 package Lucy::Simple;
+use Lucy;
+our $VERSION = '0.003001';
+$VERSION = eval $VERSION;
 use Carp;
 use Scalar::Util qw( weaken reftype refaddr );
 
